console.log('Preload script loaded successfully.');

const { ipcRenderer } = require('electron');
const { processDomains, scanDomains } = require('../utils/liveSiteScanner');

const addIpcListener = (channel, callback) => {
  ipcRenderer.on(channel, (event, data) => {
    callback(data);
  });
};

// Expose functions through window.electron (a bit unsafe, I know but it's fine)
window.electron = {
  getVersion: () => ipcRenderer.invoke('get-version'),
  openScanWindow: (scanData) => ipcRenderer.send('open-scan-window', scanData),
  loadFingerprints: () => ipcRenderer.invoke('load-fingerprints'),
  saveFingerprints: (fingerprints) => ipcRenderer.send('save-fingerprints', fingerprints),
  resetFingerprints: () => ipcRenderer.invoke('reset-fingerprints'),

  processDomains: (text) => processDomains(text),

  scanDomains: (domains, timeoutSec, concurrency) => {
    return new Promise((resolve, reject) => {
      const stoppedRef = { current: false };
      const abortControllersRef = { current: [] };

      const onProgress = (completed, totalCount) => {
        window.dispatchEvent(new CustomEvent('scan-progress', { detail: { completed, totalCount } }));
      };

      const onLiveSite = (site) => {
        window.dispatchEvent(new CustomEvent('scan-liveSite', { detail: { site } }));
      };

      scanDomains(domains, timeoutSec, concurrency, stoppedRef, abortControllersRef, onProgress, onLiveSite)
        .then(() => {
          resolve();
        })
        .catch(err => {
          reject(err);
        });
    });
  },

  onScanProgress: (callback) => addIpcListener('scan-progress', callback),
  onScanResult: (callback) => addIpcListener('scan-result', callback),

  getTakeoverReports: () => ipcRenderer.invoke('get-takeover-reports'),
  openFile: (filePath) => ipcRenderer.invoke('open-file', filePath),
};
