import React, { useState, useEffect } from 'react';
import LiveSitePage from './components/LiveSite';
import TakeoverPage from './components/Takeover';
import FingerprintsPage from './components/Fingerprints';
import ReportsPage from './components/Reports';
import AboutPage from './components/About';


function App() {
  // Default to TakeoverPage when app starts
  const [view, setView] = useState('LiveSitePage');

  useEffect(() => {
    const navMapping = {
      'nav-liveSite': 'LiveSitePage',
      'nav-takeover': 'TakeoverPage',
      'nav-fingerprints': 'FingerprintsPage',
      'nav-reports': 'ReportsPage',
      'nav-about': 'AboutPage'
    };

    const handlers = [];

    // For each ID in navMapping, add an event listener to update the view
    for (const [elementId, viewName] of Object.entries(navMapping)) {
      const link = document.getElementById(elementId);
      if (link) {
        const handleClick = (e) => {
          e.preventDefault();
          setView(viewName);
        };
        link.addEventListener('click', handleClick);
        handlers.push({ link, handleClick });
      }
    }

    return () => {
      handlers.forEach(({ link, handleClick }) => {
        link.removeEventListener('click', handleClick);
      });
    };
  }, []);

  // Render the component based on the current view state
  if (view === 'LiveSitePage') {
    return <LiveSitePage />;
  } else if (view === 'TakeoverPage') {
    return <TakeoverPage />;
  } else if (view === 'FingerprintsPage') {
    return <FingerprintsPage />;
  } else if (view === 'ReportsPage') {
    return <ReportsPage />;
  } else if (view === 'AboutPage') {
    return <AboutPage />;
  } else {
    return <div>Not Found</div>;
  }
}

export default App;
