import React, { useEffect, useState } from 'react';

function Reports() {
  const [reports, setReports] = useState([]);
  const [loading, setLoading] = useState(true);

  useEffect(() => {
    // Fetch reports on component mount
    const fetchReports = async () => {
      const fetchedReports = await window.electron.getTakeoverReports();
      setReports(fetchedReports);
      setLoading(false);
    };
    fetchReports();
  }, []);

  const handleViewFile = async (filePath) => {
    await window.electron.openFile(filePath);
  };

  if (loading) {
    return <div>Loading...</div>;
  }

  return (
    <div className="container my-4">
      <h1 className="mb-4">Takeover Scan Reports</h1>
      {reports.length === 0 ? (
        <div>No reports found</div>
      ) : (
        <table className="table table-striped">
          <thead>
            <tr>
              <th>ID</th>
              <th>File Name</th>
              <th>Creation Date</th>
              <th>View File</th>
            </tr>
          </thead>
          <tbody>
            {reports.map((report) => (
              <tr key={report.id}>
                <td>{report.id}</td>
                <td>{report.name}</td>
                <td>{report.creationDate}</td>
                <td>
                  <button
                    className="btn btn-primary btn-sm"
                    onClick={() => handleViewFile(report.path)}
                  >
                    View File
                  </button>
                </td>
              </tr>
            ))}
          </tbody>
        </table>
      )}
    </div>
  );
}

export default Reports;
