// webpack.config.js
const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
// Removed CopyWebpackPlugin since we no longer need to copy preload.js

module.exports = {
  entry: {
    main: './src/renderer/index.js',
    scanWindow: './src/renderer/scanWindow.jsx'
  },
  output: {
    filename: '[name].bundle.js',
    path: path.resolve(__dirname, 'dist'),
    clean: true, 
  },
  target: 'electron-renderer', 
  module: {
    rules: [
      {
        test: /\.(js|jsx)$/, 
        exclude: /node_modules/,
        use: {
          loader: 'babel-loader',
          options: {
            presets: [
              '@babel/preset-env',
              '@babel/preset-react' 
            ],
          },
        },
      },
      {
        test: /\.css$/, 
        use: [
          'style-loader', 
          'css-loader',  
        ],
      },
    ],
  },
  resolve: {
    extensions: ['.js', '.jsx'], 
    fallback: {
      fs: false,
      path: false,
      os: false,
    },
  },
  plugins: [
    // Handle base.html
    new HtmlWebpackPlugin({
      template: './src/renderer/base.html',
      filename: 'base.html',
      chunks: ['main'] 
    }),
    // Handle scanWindow.html
    new HtmlWebpackPlugin({
      template: './src/renderer/scanWindow.html',
      filename: 'scanWindow.html',
      chunks: ['scanWindow']
    }),
    // Removed CopyWebpackPlugin for preload.js
  ],
  devServer: {
    static: {
      directory: path.join(__dirname, 'dist'),
    },
    compress: true,
    port: 9000,
    open: true,
  },
  mode: 'production',
};
